Learn R Programming

crwbmetareg (version 1.0)

Meta regression using cluster robust wild bootstrap: Meta regression using cluster robust wild bootstrap

Description

Meta regression using cluster robust wild bootstrap.

Usage

crwbmetareg(target, se, dataset, cluster, weights, boot.reps = 1000,
prog.bar = FALSE, seed = NULL)

Value

A vector with two p-values. One for the constant and one for the cofficient of the "se".

Arguments

target

A vector with the effect sizes.

se

A vector with the standard errors, or the variances, of the effect sizes.

dataset

A matrix or data.frame with the independent variables.

cluster

A vector indicating the clusters.

weights

A vector with the inverse of the the variances of the effect sizes.

boot.reps

The number of bootstrap re-samples to generate.

prog.bar

If you want the progress bar to appear set this equal to TRUE.

seed

IF you want the results to be rerpoducible set this equal to TRUE.

Author

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

Details

It implements metaregression using cluster robust wild bootstrap to compute the p-values. See references for this.

The function uses a modification of the function "cluster.wild.glm()" of the package "clusterSEs".

References

Oczkowski, E. and Doucouliagos, H. (2015). Wine prices and quality ratings: a meta-regression analysis. American Journal of Agricultural Economics, 97(1): 103--121.

Cameron, A. C., Gelbach, J. B. and Miller, D. L. (2008). Bootstrap-based improvements for inference with clustered errors. The Review of Economics and Statistics, 90(3): 414--427.

See Also

fatpet

Examples

Run this code
y <- rnorm(50)
se <- rexp(50, 3)
cluster <- sample(1:20, 50, replace = TRUE)
dataset <- matrix( rnorm(50 * 2), ncol = 2 )
fatpet(y, se, dataset, cluster, weights = se^2, boot.reps = 100)

Run the code above in your browser using DataLab